var NanoVDB_8h =
[
    [ "ValueIndex", "classnanovdb_1_1ValueIndex.html", null ],
    [ "ValueOnIndex", "classnanovdb_1_1ValueOnIndex.html", null ],
    [ "ValueIndexMask", "classnanovdb_1_1ValueIndexMask.html", null ],
    [ "ValueOnIndexMask", "classnanovdb_1_1ValueOnIndexMask.html", null ],
    [ "ValueMask", "classnanovdb_1_1ValueMask.html", null ],
    [ "Half", "classnanovdb_1_1Half.html", null ],
    [ "Fp4", "classnanovdb_1_1Fp4.html", null ],
    [ "Fp8", "classnanovdb_1_1Fp8.html", null ],
    [ "Fp16", "classnanovdb_1_1Fp16.html", null ],
    [ "FpN", "classnanovdb_1_1FpN.html", null ],
    [ "Point", "classnanovdb_1_1Point.html", null ],
    [ "BuildTraits&lt; T &gt;", "structnanovdb_1_1BuildTraits.html", "structnanovdb_1_1BuildTraits" ],
    [ "BuildToValueMap&lt; T &gt;", "structnanovdb_1_1BuildToValueMap.html", "structnanovdb_1_1BuildToValueMap" ],
    [ "BuildToValueMap&lt; ValueIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndex_01_4" ],
    [ "BuildToValueMap&lt; ValueOnIndex &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndex_01_4" ],
    [ "BuildToValueMap&lt; ValueIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueIndexMask_01_4" ],
    [ "BuildToValueMap&lt; ValueOnIndexMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueOnIndexMask_01_4" ],
    [ "BuildToValueMap&lt; ValueMask &gt;", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01ValueMask_01_4" ],
    [ "BuildToValueMap&lt; Half &gt;", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Half_01_4" ],
    [ "BuildToValueMap&lt; Fp4 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp4_01_4" ],
    [ "BuildToValueMap&lt; Fp8 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp8_01_4" ],
    [ "BuildToValueMap&lt; Fp16 &gt;", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Fp16_01_4" ],
    [ "BuildToValueMap&lt; FpN &gt;", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01FpN_01_4" ],
    [ "BuildToValueMap&lt; Point &gt;", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4.html", "structnanovdb_1_1BuildToValueMap_3_01Point_01_4" ],
    [ "Version", "classnanovdb_1_1Version.html", "classnanovdb_1_1Version" ],
    [ "TensorTraits&lt; T, 0 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_010_01_4" ],
    [ "TensorTraits&lt; T, 1 &gt;", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4.html", "structnanovdb_1_1TensorTraits_3_01T_00_011_01_4" ],
    [ "FloatTraits&lt; T, int &gt;", "structnanovdb_1_1FloatTraits.html", "structnanovdb_1_1FloatTraits" ],
    [ "FloatTraits&lt; T, 8 &gt;", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4.html", "structnanovdb_1_1FloatTraits_3_01T_00_018_01_4" ],
    [ "FloatTraits&lt; bool, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01bool_00_011_01_4" ],
    [ "FloatTraits&lt; ValueIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndex_00_011_01_4" ],
    [ "FloatTraits&lt; ValueIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueIndexMask_00_011_01_4" ],
    [ "FloatTraits&lt; ValueOnIndex, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndex_00_011_01_4" ],
    [ "FloatTraits&lt; ValueOnIndexMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueOnIndexMask_00_011_01_4" ],
    [ "FloatTraits&lt; ValueMask, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01ValueMask_00_011_01_4" ],
    [ "FloatTraits&lt; Point, 1 &gt;", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4.html", "structnanovdb_1_1FloatTraits_3_01Point_00_011_01_4" ],
    [ "BitArray&lt; 8 &gt;", "structnanovdb_1_1BitArray_3_018_01_4.html", "structnanovdb_1_1BitArray_3_018_01_4" ],
    [ "BitArray&lt; 16 &gt;", "structnanovdb_1_1BitArray_3_0116_01_4.html", "structnanovdb_1_1BitArray_3_0116_01_4" ],
    [ "BitArray&lt; 32 &gt;", "structnanovdb_1_1BitArray_3_0132_01_4.html", "structnanovdb_1_1BitArray_3_0132_01_4" ],
    [ "BitArray&lt; 64 &gt;", "structnanovdb_1_1BitArray_3_0164_01_4.html", "structnanovdb_1_1BitArray_3_0164_01_4" ],
    [ "BitFlags&lt; N &gt;", "classnanovdb_1_1BitFlags.html", "classnanovdb_1_1BitFlags" ],
    [ "Mask&lt; LOG2DIM &gt;", "classnanovdb_1_1Mask.html", "classnanovdb_1_1Mask" ],
    [ "Mask&lt; LOG2DIM &gt;::Iterator&lt; On &gt;", "classnanovdb_1_1Mask_1_1Iterator.html", "classnanovdb_1_1Mask_1_1Iterator" ],
    [ "Mask&lt; LOG2DIM &gt;::DenseIterator", "classnanovdb_1_1Mask_1_1DenseIterator.html", "classnanovdb_1_1Mask_1_1DenseIterator" ],
    [ "Map", "structnanovdb_1_1Map.html", "structnanovdb_1_1Map" ],
    [ "GridBlindMetaData", "structnanovdb_1_1GridBlindMetaData.html", "structnanovdb_1_1GridBlindMetaData" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_010_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 0 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_010_01_4" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_011_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 1 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_011_01_4" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_012_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 2 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_012_01_4" ],
    [ "NodeTrait&lt; GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01GridOrTreeOrRootT_00_013_01_4" ],
    [ "NodeTrait&lt; const GridOrTreeOrRootT, 3 &gt;", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4.html", "structnanovdb_1_1NodeTrait_3_01const_01GridOrTreeOrRootT_00_013_01_4" ],
    [ "Checksum", "classnanovdb_1_1Checksum.html", "classnanovdb_1_1Checksum" ],
    [ "GridData", "structnanovdb_1_1GridData.html", "structnanovdb_1_1GridData" ],
    [ "Grid&lt; TreeT &gt;", "classnanovdb_1_1Grid.html", "classnanovdb_1_1Grid" ],
    [ "TreeData", "structnanovdb_1_1TreeData.html", "structnanovdb_1_1TreeData" ],
    [ "GridTree&lt; GridT &gt;", "structnanovdb_1_1GridTree.html", "structnanovdb_1_1GridTree" ],
    [ "GridTree&lt; const GridT &gt;", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4.html", "structnanovdb_1_1GridTree_3_01const_01GridT_01_4" ],
    [ "Tree&lt; RootT &gt;", "classnanovdb_1_1Tree.html", "classnanovdb_1_1Tree" ],
    [ "RootData&lt; ChildT &gt;", "structnanovdb_1_1RootData.html", "structnanovdb_1_1RootData" ],
    [ "RootData&lt; ChildT &gt;::Tile", "structnanovdb_1_1RootData_1_1Tile.html", "structnanovdb_1_1RootData_1_1Tile" ],
    [ "RootData&lt; ChildT &gt;::TileIter&lt; DataT &gt;", "classnanovdb_1_1RootData_1_1TileIter.html", "classnanovdb_1_1RootData_1_1TileIter" ],
    [ "RootNode&lt; ChildT &gt;", "classnanovdb_1_1RootNode.html", "classnanovdb_1_1RootNode" ],
    [ "RootNode&lt; ChildT &gt;::BaseIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1BaseIter.html", "classnanovdb_1_1RootNode_1_1BaseIter" ],
    [ "RootNode&lt; ChildT &gt;::ChildIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1ChildIter.html", "classnanovdb_1_1RootNode_1_1ChildIter" ],
    [ "RootNode&lt; ChildT &gt;::ValueIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1ValueIter.html", "classnanovdb_1_1RootNode_1_1ValueIter" ],
    [ "RootNode&lt; ChildT &gt;::ValueOnIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1ValueOnIter.html", "classnanovdb_1_1RootNode_1_1ValueOnIter" ],
    [ "RootNode&lt; ChildT &gt;::DenseIter&lt; RootT &gt;", "classnanovdb_1_1RootNode_1_1DenseIter.html", "classnanovdb_1_1RootNode_1_1DenseIter" ],
    [ "InternalData&lt; ChildT, LOG2DIM &gt;", "structnanovdb_1_1InternalData.html", "structnanovdb_1_1InternalData" ],
    [ "InternalData&lt; ChildT, LOG2DIM &gt;::Tile", "unionnanovdb_1_1InternalData_1_1Tile.html", "unionnanovdb_1_1InternalData_1_1Tile" ],
    [ "InternalNode&lt; ChildT, Log2Dim &gt;", "classnanovdb_1_1InternalNode.html", "classnanovdb_1_1InternalNode" ],
    [ "InternalNode&lt; ChildT, Log2Dim &gt;::ChildIter&lt; ParentT &gt;", "classnanovdb_1_1InternalNode_1_1ChildIter.html", "classnanovdb_1_1InternalNode_1_1ChildIter" ],
    [ "InternalNode&lt; ChildT, Log2Dim &gt;::ValueIterator", "classnanovdb_1_1InternalNode_1_1ValueIterator.html", "classnanovdb_1_1InternalNode_1_1ValueIterator" ],
    [ "InternalNode&lt; ChildT, Log2Dim &gt;::ValueOnIterator", "classnanovdb_1_1InternalNode_1_1ValueOnIterator.html", "classnanovdb_1_1InternalNode_1_1ValueOnIterator" ],
    [ "InternalNode&lt; ChildT, Log2Dim &gt;::DenseIterator", "classnanovdb_1_1InternalNode_1_1DenseIterator.html", "classnanovdb_1_1InternalNode_1_1DenseIterator" ],
    [ "LeafData&lt; ValueT, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData.html", "structnanovdb_1_1LeafData" ],
    [ "LeafFnBase&lt; CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafFnBase.html", "structnanovdb_1_1LeafFnBase" ],
    [ "LeafData&lt; Fp4, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp4_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; Fp8, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp8_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; Fp16, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Fp16_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; FpN, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01FpN_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; bool, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01bool_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafIndexBase&lt; CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafIndexBase.html", "structnanovdb_1_1LeafIndexBase" ],
    [ "LeafData&lt; ValueIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueOnIndex, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndex_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; ValueOnIndexMask, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01ValueOnIndexMask_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafData&lt; Point, CoordT, MaskT, LOG2DIM &gt;", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4.html", "structnanovdb_1_1LeafData_3_01Point_00_01CoordT_00_01MaskT_00_01LOG2DIM_01_4" ],
    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;", "classnanovdb_1_1LeafNode.html", "classnanovdb_1_1LeafNode" ],
    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ChildNodeType", "structnanovdb_1_1LeafNode_1_1ChildNodeType.html", "structnanovdb_1_1LeafNode_1_1ChildNodeType" ],
    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ValueOnIterator", "classnanovdb_1_1LeafNode_1_1ValueOnIterator.html", "classnanovdb_1_1LeafNode_1_1ValueOnIterator" ],
    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ValueOffIterator", "classnanovdb_1_1LeafNode_1_1ValueOffIterator.html", "classnanovdb_1_1LeafNode_1_1ValueOffIterator" ],
    [ "LeafNode&lt; BuildT, CoordT, MaskT, Log2Dim &gt;::ValueIterator", "classnanovdb_1_1LeafNode_1_1ValueIterator.html", "classnanovdb_1_1LeafNode_1_1ValueIterator" ],
    [ "NanoNode&lt; BuildT, 0 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_010_01_4" ],
    [ "NanoNode&lt; BuildT, 1 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_011_01_4" ],
    [ "NanoNode&lt; BuildT, 2 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_012_01_4" ],
    [ "NanoNode&lt; BuildT, 3 &gt;", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4.html", "structnanovdb_1_1NanoNode_3_01BuildT_00_013_01_4" ],
    [ "ReadAccessor&lt; BuildT, -1, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01-1_00_01-1_00_01-1_01_4" ],
    [ "ReadAccessor&lt; BuildT, LEVEL0, -1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01-1_00_01-1_01_4" ],
    [ "ReadAccessor&lt; BuildT, LEVEL0, LEVEL1, -1 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_01LEVEL0_00_01LEVEL1_00_01-1_01_4" ],
    [ "ReadAccessor&lt; BuildT, 0, 1, 2 &gt;", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4.html", "classnanovdb_1_1ReadAccessor_3_01BuildT_00_010_00_011_00_012_01_4" ],
    [ "GridMetaData", "classnanovdb_1_1GridMetaData.html", "classnanovdb_1_1GridMetaData" ],
    [ "PointAccessor&lt; AttT, BuildT &gt;", "classnanovdb_1_1PointAccessor.html", "classnanovdb_1_1PointAccessor" ],
    [ "PointAccessor&lt; AttT, Point &gt;", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4.html", "classnanovdb_1_1PointAccessor_3_01AttT_00_01Point_01_4" ],
    [ "ChannelAccessor&lt; ChannelT, IndexT &gt;", "classnanovdb_1_1ChannelAccessor.html", "classnanovdb_1_1ChannelAccessor" ],
    [ "FileHeader", "structnanovdb_1_1io_1_1FileHeader.html", "structnanovdb_1_1io_1_1FileHeader" ],
    [ "FileMetaData", "structnanovdb_1_1io_1_1FileMetaData.html", "structnanovdb_1_1io_1_1FileMetaData" ],
    [ "GetValue&lt; BuildT &gt;", "structnanovdb_1_1GetValue.html", "structnanovdb_1_1GetValue" ],
    [ "SetValue&lt; BuildT &gt;", "structnanovdb_1_1SetValue.html", "structnanovdb_1_1SetValue" ],
    [ "SetVoxel&lt; BuildT &gt;", "structnanovdb_1_1SetVoxel.html", "structnanovdb_1_1SetVoxel" ],
    [ "GetState&lt; BuildT &gt;", "structnanovdb_1_1GetState.html", "structnanovdb_1_1GetState" ],
    [ "GetDim&lt; BuildT &gt;", "structnanovdb_1_1GetDim.html", "structnanovdb_1_1GetDim" ],
    [ "GetLeaf&lt; BuildT &gt;", "structnanovdb_1_1GetLeaf.html", "structnanovdb_1_1GetLeaf" ],
    [ "GetLower&lt; BuildT &gt;", "structnanovdb_1_1GetLower.html", "structnanovdb_1_1GetLower" ],
    [ "GetUpper&lt; BuildT &gt;", "structnanovdb_1_1GetUpper.html", "structnanovdb_1_1GetUpper" ],
    [ "GetTile&lt; BuildT &gt;", "structnanovdb_1_1GetTile.html", "structnanovdb_1_1GetTile" ],
    [ "ProbeValue&lt; BuildT &gt;", "structnanovdb_1_1ProbeValue.html", "structnanovdb_1_1ProbeValue" ],
    [ "GetNodeInfo&lt; BuildT &gt;", "structnanovdb_1_1GetNodeInfo.html", "structnanovdb_1_1GetNodeInfo" ],
    [ "GetNodeInfo&lt; BuildT &gt;::NodeInfo", "structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html", "structnanovdb_1_1GetNodeInfo_1_1NodeInfo" ],
    [ "NANOVDB_ALIGN", "NanoVDB_8h.html#a4f8b26821816e0334dfd79e0cbd39c4d", null ],
    [ "NANOVDB_DATA_ALIGNMENT", "NanoVDB_8h.html#a54db29617e4e954de4af9721a183f789", null ],
    [ "NANOVDB_FPN_BRANCHLESS", "NanoVDB_8h.html#a01604c4a002e700cf39c3c3a2dc2eb5c", null ],
    [ "NANOVDB_MAGIC_FILE", "NanoVDB_8h.html#a07ef91a6ad762e2e320f2032c2249c63", null ],
    [ "NANOVDB_MAGIC_GRID", "NanoVDB_8h.html#a36c9da50c4e9e9e1cd4180921f0a0ab2", null ],
    [ "NANOVDB_MAGIC_MASK", "NanoVDB_8h.html#a27c1f0f2bf7b8fe1c8fed953677d08ae", null ],
    [ "NANOVDB_MAGIC_NUMB", "NanoVDB_8h.html#a990442e1e831eb77440c51eafeda90b5", null ],
    [ "NANOVDB_MAJOR_VERSION_NUMBER", "NanoVDB_8h.html#a5c3e462d9f4cf1358ad8fda5d34b0ab1", null ],
    [ "NANOVDB_MINOR_VERSION_NUMBER", "NanoVDB_8h.html#a3ac48c8766ed12e2d673a9f3809365e1", null ],
    [ "NANOVDB_PATCH_VERSION_NUMBER", "NanoVDB_8h.html#ab7ea3d375035a51f6e536b6f496dda64", null ],
    [ "NANOVDB_USE_NEW_MAGIC_NUMBERS", "NanoVDB_8h.html#a8cf1f4b7936a9ad6e92358dc22b48a79", null ],
    [ "NANOVDB_USE_SINGLE_ROOT_KEY", "NanoVDB_8h.html#a4af192d64f30b1b6bda1a3e6ba93df11", null ],
    [ "TBB_SUPPRESS_DEPRECATED_MESSAGES", "NanoVDB_8h.html#a7f41130cb850d9fcf11ba3a25c35ee6d", null ],
    [ "nanovdb::BoolGrid", "namespacenanovdb.html#a44c7484144fab7fb2c436e938e2d87ce", null ],
    [ "nanovdb::BoolTree", "namespacenanovdb.html#ad72af753c2016641acc019c714d77f97", null ],
    [ "nanovdb::DefaultReadAccessor", "namespacenanovdb.html#a119ba501e2785cede6a233e164587646", null ],
    [ "nanovdb::DoubleGrid", "namespacenanovdb.html#ae4044ab7ef1bfe752d228fe84ecd996e", null ],
    [ "nanovdb::DoubleTree", "namespacenanovdb.html#a89653a5be991c6944d23f78ab9a0d165", null ],
    [ "nanovdb::FloatGrid", "namespacenanovdb.html#a2ae45d4df056c7d0d936a496fec925ee", null ],
    [ "nanovdb::FloatTree", "namespacenanovdb.html#aea5691a16e345b5c9ccfecc9bd421aa3", null ],
    [ "nanovdb::Fp16Grid", "namespacenanovdb.html#a2add8370a07ef764607a1c02780a7ac9", null ],
    [ "nanovdb::Fp16Tree", "namespacenanovdb.html#ab24e02bf14f76279b005a547b7d7f014", null ],
    [ "nanovdb::Fp4Grid", "namespacenanovdb.html#a108f0bf38170451c71ed8757c5a252ad", null ],
    [ "nanovdb::Fp4Tree", "namespacenanovdb.html#aee38b4e88bb1acfba039bec3bda151fc", null ],
    [ "nanovdb::Fp8Grid", "namespacenanovdb.html#a6823526f3faca27de16d19bd6da323bd", null ],
    [ "nanovdb::Fp8Tree", "namespacenanovdb.html#a957c939d1a187968289b6668e4bbfccd", null ],
    [ "nanovdb::FpNGrid", "namespacenanovdb.html#aea5067ced91f635731e7bdfd93d8e4ab", null ],
    [ "nanovdb::FpNTree", "namespacenanovdb.html#ab70dae51348229b857c5baeb55634ede", null ],
    [ "nanovdb::IndexGrid", "namespacenanovdb.html#ad24384a4bda82649992fd5faf8fbbea4", null ],
    [ "nanovdb::IndexMaskGrid", "namespacenanovdb.html#ae110e094c8acbf86476a56e1a934db48", null ],
    [ "nanovdb::IndexMaskTree", "namespacenanovdb.html#ab435418aa35a94ca3e0e07106cdade3a", null ],
    [ "nanovdb::IndexTree", "namespacenanovdb.html#a8b2ce743deac24d5783b4c9c4ab2413c", null ],
    [ "nanovdb::Int32Grid", "namespacenanovdb.html#ad5315505f8bc162f1d371ea1d8beb559", null ],
    [ "nanovdb::Int32Tree", "namespacenanovdb.html#a7e3e7b41a25f7e3ea990ede00acf4b4d", null ],
    [ "nanovdb::Int64Grid", "namespacenanovdb.html#a6dac52fd0c0a5f0eb9ccac0050b951f9", null ],
    [ "nanovdb::Int64Tree", "namespacenanovdb.html#aa670cd82320c67592342219ede77f80a", null ],
    [ "nanovdb::MaskGrid", "namespacenanovdb.html#ab26e09c39606fb93509615cd9120d4b0", null ],
    [ "nanovdb::MaskTree", "namespacenanovdb.html#a58500ecb4f7084a799ab81316cbb6429", null ],
    [ "nanovdb::NanoGrid", "namespacenanovdb.html#a1eba1ecdc176671d534794bcd6604e8a", null ],
    [ "nanovdb::NanoLeaf", "namespacenanovdb.html#a7f5e063d2e00f072512023f71730e30c", null ],
    [ "nanovdb::NanoLower", "namespacenanovdb.html#a36ca82ec691cb6e38cd5d1910b38f849", null ],
    [ "nanovdb::NanoRoot", "namespacenanovdb.html#a537a4d5b445c163b39b264a0788e4acc", null ],
    [ "nanovdb::NanoTree", "namespacenanovdb.html#a7414dd62bd9510809baa893a7fe34f45", null ],
    [ "nanovdb::NanoUpper", "namespacenanovdb.html#a4a37fa5d76eaf814e849b1041127f4d6", null ],
    [ "nanovdb::OnIndexGrid", "namespacenanovdb.html#a64b12ea5a9ec908880ce61ade6cfe2c7", null ],
    [ "nanovdb::OnIndexMaskGrid", "namespacenanovdb.html#a1f5a34bcde78736b2a932d86dad38952", null ],
    [ "nanovdb::OnIndexMaskTree", "namespacenanovdb.html#a52f690d3f9a2e77d10430b2246e5135a", null ],
    [ "nanovdb::OnIndexTree", "namespacenanovdb.html#a81835ea06bc64d48949f2d38c055dfd7", null ],
    [ "nanovdb::PointGrid", "namespacenanovdb.html#a5179ca634b95e51e1e60c3137966121a", null ],
    [ "nanovdb::UInt32Grid", "namespacenanovdb.html#a94e1a92c88ebc5f570edaaf87d7b478e", null ],
    [ "nanovdb::UInt32Tree", "namespacenanovdb.html#ad9b036304ed2c809aed2b227c786055c", null ],
    [ "nanovdb::Vec3dGrid", "namespacenanovdb.html#a50c6d355efc86c8636e15ec43bc73600", null ],
    [ "nanovdb::Vec3dTree", "namespacenanovdb.html#ab09734db37c7e5175ebd599a3fbc2e42", null ],
    [ "nanovdb::Vec3fGrid", "namespacenanovdb.html#a2f55df6ff6e3e428413c6695c27ebf06", null ],
    [ "nanovdb::Vec3fTree", "namespacenanovdb.html#ad6e9f607aae5a2c0b3a4a98e9c91cc78", null ],
    [ "nanovdb::Vec3IGrid", "namespacenanovdb.html#a667cf1ae46101764bb15844228daef4d", null ],
    [ "nanovdb::Vec3ITree", "namespacenanovdb.html#a262735ef3ecf29bd0fd96861e644450b", null ],
    [ "nanovdb::Vec4dGrid", "namespacenanovdb.html#a38929ef24ddc9df8bb8ee096c8a21663", null ],
    [ "nanovdb::Vec4dTree", "namespacenanovdb.html#a91fd90b78e816b5286c89d9f5d59dd02", null ],
    [ "nanovdb::Vec4fGrid", "namespacenanovdb.html#a1e6db5e5a91cff3cd3929f2b634b91d7", null ],
    [ "nanovdb::Vec4fTree", "namespacenanovdb.html#aa9473db48ae9bdb558ed7af023ad9f9f", null ],
    [ "nanovdb::CheckMode", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5", [
      [ "nanovdb::CheckMode::Disable", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5abcfaccebf745acfd5e75351095a5394a", null ],
      [ "nanovdb::CheckMode::Empty", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5ace2c8aed9c2fa0cfbed56cbda4d8bf07", null ],
      [ "nanovdb::CheckMode::Half", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5ac48615a1bc4197056d522af276aa5a85", null ],
      [ "nanovdb::CheckMode::Partial", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a44ffd38a6dea695cbe2b34efdcc6cf27", null ],
      [ "nanovdb::CheckMode::Default", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a7a1920d61156abc05a60135aefe8bc67", null ],
      [ "nanovdb::CheckMode::Full", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5abbd47109890259c0127154db1af26c75", null ],
      [ "nanovdb::CheckMode::End", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "nanovdb::CheckMode::StrLen", "namespacenanovdb.html#a4e857e4b13a164e4df80f9282a71d0b5a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "nanovdb::io::Codec", "namespacenanovdb_1_1io.html#ae42f8cdb9215c4db646cf1021c45648a", [
      [ "nanovdb::io::Codec::NONE", "namespacenanovdb_1_1io.html#ae42f8cdb9215c4db646cf1021c45648aab50339a10e1de285ac99d4c3990b8693", null ],
      [ "nanovdb::io::Codec::ZIP", "namespacenanovdb_1_1io.html#ae42f8cdb9215c4db646cf1021c45648aa4348f938bbddd8475e967ccb47ecb234", null ],
      [ "nanovdb::io::Codec::BLOSC", "namespacenanovdb_1_1io.html#ae42f8cdb9215c4db646cf1021c45648aa90761c3ee2998674f30361338fde4875", null ],
      [ "nanovdb::io::Codec::End", "namespacenanovdb_1_1io.html#ae42f8cdb9215c4db646cf1021c45648aa87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "nanovdb::io::Codec::StrLen", "namespacenanovdb_1_1io.html#ae42f8cdb9215c4db646cf1021c45648aa3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "nanovdb::GridBlindDataClass", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757", [
      [ "nanovdb::GridBlindDataClass::Unknown", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "nanovdb::GridBlindDataClass::IndexArray", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757aacaaf217c6534c34b63edcbbf5b422d5", null ],
      [ "nanovdb::GridBlindDataClass::AttributeArray", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757ac9f80f42ad87935afb0e58d931cac637", null ],
      [ "nanovdb::GridBlindDataClass::GridName", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757ae2b04d8578fddb43d1dd7b17e0938f8c", null ],
      [ "nanovdb::GridBlindDataClass::ChannelArray", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757a6c726c41d16ff146b47662a778b25364", null ],
      [ "nanovdb::GridBlindDataClass::End", "namespacenanovdb.html#a88f2aa0b172a229831be2b4e1c70e757a87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "nanovdb::GridBlindDataSemantic", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1ea", [
      [ "nanovdb::GridBlindDataSemantic::Unknown", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "nanovdb::GridBlindDataSemantic::PointPosition", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa5c3b53b495a3a3675a13b9f920f65c68", null ],
      [ "nanovdb::GridBlindDataSemantic::PointColor", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa755bd5308e91265618dfe6d16bab5827", null ],
      [ "nanovdb::GridBlindDataSemantic::PointNormal", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaceed7a7fc0fffbe1eeda2b27b73fe970", null ],
      [ "nanovdb::GridBlindDataSemantic::PointRadius", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa41b2451b41584afbc9a2aae375df887e", null ],
      [ "nanovdb::GridBlindDataSemantic::PointVelocity", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa844465b2d78929eccef953b476a1d3ae", null ],
      [ "nanovdb::GridBlindDataSemantic::PointId", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaffee0e6895c7bbb8ad956f9cdc43f05f", null ],
      [ "nanovdb::GridBlindDataSemantic::WorldCoords", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaad398e268b887627d9060fa8107829c4", null ],
      [ "nanovdb::GridBlindDataSemantic::GridCoords", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaaacf4f1b1f76cca12828cb0c1f61262c7", null ],
      [ "nanovdb::GridBlindDataSemantic::VoxelCoords", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa7572a22ae44e59c3d4f906392ccb0081", null ],
      [ "nanovdb::GridBlindDataSemantic::End", "namespacenanovdb.html#ad302dde29b8cf276217e7db12f56e1eaa87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "nanovdb::GridClass", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538", [
      [ "nanovdb::GridClass::Unknown", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "nanovdb::GridClass::LevelSet", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538af75f97f8f1058acd62c93bf29de9f49e", null ],
      [ "nanovdb::GridClass::FogVolume", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a2863212e81b8902a3bff99d2006ce625", null ],
      [ "nanovdb::GridClass::Staggered", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538af421d06a10620aa57ae6ebaec46cffe9", null ],
      [ "nanovdb::GridClass::PointIndex", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538ac6672402f95bb6a565b10c45206e7073", null ],
      [ "nanovdb::GridClass::PointData", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538ae540450fb956cd9dbb96f979e5939d0f", null ],
      [ "nanovdb::GridClass::Topology", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a99571eecaa5c5d622bb0d1f855752d5f", null ],
      [ "nanovdb::GridClass::VoxelVolume", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a72123f854e9cd15456c7bec1065d6fb2", null ],
      [ "nanovdb::GridClass::IndexGrid", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538acb1be051e0c63143e5435c90f3145716", null ],
      [ "nanovdb::GridClass::TensorGrid", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a592c282b872320d6af38c4155b1692fe", null ],
      [ "nanovdb::GridClass::End", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "nanovdb::GridClass::StrLen", "namespacenanovdb.html#a4b4b8c3c2fb135839b2d1b020cc06538a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "nanovdb::GridFlags", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2", [
      [ "nanovdb::GridFlags::HasLongGridName", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a23e9b13b57fa3a257e1e4fde6cf56877", null ],
      [ "nanovdb::GridFlags::HasBBox", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a9f37cc46fd863dea1ffb9c259dbb7c00", null ],
      [ "nanovdb::GridFlags::HasMinMax", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a263a3063d285be389e148e85421039f7", null ],
      [ "nanovdb::GridFlags::HasAverage", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a0a62d056892be87e60f9e076e1527ad7", null ],
      [ "nanovdb::GridFlags::HasStdDeviation", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a162fc94d271294bc85d49f150e78e7f6", null ],
      [ "nanovdb::GridFlags::IsBreadthFirst", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2ad502f4662163332c1da3eee696195a5d", null ],
      [ "nanovdb::GridFlags::End", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "nanovdb::GridFlags::StrLen", "namespacenanovdb.html#a5e907cd4aa4176a71501fbc59bcd6bb2a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "nanovdb::GridType", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0", [
      [ "nanovdb::GridType::Unknown", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "nanovdb::GridType::Float", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a22ae0e2b89e5e3d477f988cc36d3272b", null ],
      [ "nanovdb::GridType::Double", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ad909d38d705ce75386dd86e611a82f5b", null ],
      [ "nanovdb::GridType::Int16", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a39bc2ae44b184207f560ff8619823208", null ],
      [ "nanovdb::GridType::Int32", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac06129f6e6e15c09328365e553f1dc31", null ],
      [ "nanovdb::GridType::Int64", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0afbde23b11d7e59af7828e81144c8b487", null ],
      [ "nanovdb::GridType::Vec3f", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ae955b77fe1f267cbe6bb898c6be66369", null ],
      [ "nanovdb::GridType::Vec3d", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ad5b40ccec7be098557d1e35969a4bec2", null ],
      [ "nanovdb::GridType::Mask", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a4a18312b5b75f549d5551e5912ad6ebf", null ],
      [ "nanovdb::GridType::Half", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac48615a1bc4197056d522af276aa5a85", null ],
      [ "nanovdb::GridType::UInt32", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ae7956ed7be1c5025a27ed3cb42a396bd", null ],
      [ "nanovdb::GridType::Boolean", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a27226c864bac7454a8504f8edb15d95b", null ],
      [ "nanovdb::GridType::RGBA8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ab4b279046a02077466fa26cabb00c642", null ],
      [ "nanovdb::GridType::Fp4", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a3f84fc6967b5ab092b8a07a4b5e88cc5", null ],
      [ "nanovdb::GridType::Fp8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a7ca0d07c477bfb061380581840f9d8b1", null ],
      [ "nanovdb::GridType::Fp16", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0afe294cd6f9909150e9ab48cdebcc2caa", null ],
      [ "nanovdb::GridType::FpN", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ab2baef78f0e38560077dd76b13478677", null ],
      [ "nanovdb::GridType::Vec4f", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a34d3ecfb06b4ed93cf8d67757d968331", null ],
      [ "nanovdb::GridType::Vec4d", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a6344916c470b2c1e9fb91cbdff70b601", null ],
      [ "nanovdb::GridType::Index", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a88fa71f0a6e0dfedbb46d91cc0b37a50", null ],
      [ "nanovdb::GridType::OnIndex", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac3922cc108832ec8e5a5702cdc9cb283", null ],
      [ "nanovdb::GridType::IndexMask", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a6f46c6bc461374535922d91fde2c9a61", null ],
      [ "nanovdb::GridType::OnIndexMask", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a4af32108e62136a074a40a815f3994f9", null ],
      [ "nanovdb::GridType::PointIndex", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ac6672402f95bb6a565b10c45206e7073", null ],
      [ "nanovdb::GridType::Vec3u8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a1451f42309a1af14dd6f615503ea9744", null ],
      [ "nanovdb::GridType::Vec3u16", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a58feb259a4420759cff617e92d459498", null ],
      [ "nanovdb::GridType::UInt8", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0ab31df9c476d20e85ff898121efe11b5a", null ],
      [ "nanovdb::GridType::End", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "nanovdb::GridType::StrLen", "namespacenanovdb.html#a4c0dc82510efc445233bd15b340bfeb0a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "nanovdb::MagicType", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108", [
      [ "nanovdb::MagicType::Unknown", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "nanovdb::MagicType::OpenVDB", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a011b949ced7ed48dafe7b08ae740dae9", null ],
      [ "nanovdb::MagicType::NanoVDB", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a88a126c378054f0ba911c58116fdaf43", null ],
      [ "nanovdb::MagicType::NanoGrid", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a723913be2557a3dcfe17866296fee5b6", null ],
      [ "nanovdb::MagicType::NanoFile", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108acabfde358eaaeaff8df932f1346f0bcf", null ],
      [ "nanovdb::MagicType::End", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "nanovdb::MagicType::StrLen", "namespacenanovdb.html#aa0895e3576a80fc34b25fff786b1d108a3b057f70b2c3c127066f1555ea066942", null ]
    ] ],
    [ "nanovdb::PointType", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699b", [
      [ "nanovdb::PointType::Disable", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699babcfaccebf745acfd5e75351095a5394a", null ],
      [ "nanovdb::PointType::PointID", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba86bbf6c1606325c980585d136866fb2f", null ],
      [ "nanovdb::PointType::World64", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699bad7ae19b0bbc6fe3695b1b8f6f36e932f", null ],
      [ "nanovdb::PointType::World32", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba91a7dc3cc2ea0ed2215b1ade139b1bcf", null ],
      [ "nanovdb::PointType::Grid64", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699bae145abf20f8b2a7c8d5612e8961e9b32", null ],
      [ "nanovdb::PointType::Grid32", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba12c5c9b2e2a77edcefa82d80dde5ff80", null ],
      [ "nanovdb::PointType::Voxel32", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba0522330b37aac86ef9303c0686b543d4", null ],
      [ "nanovdb::PointType::Voxel16", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699bacf9278b5e5db74c7c099e8694a2476c4", null ],
      [ "nanovdb::PointType::Voxel8", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba1784e0952706051e3000cc167eec72a5", null ],
      [ "nanovdb::PointType::Default", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba7a1920d61156abc05a60135aefe8bc67", null ],
      [ "nanovdb::PointType::End", "namespacenanovdb.html#a141c0fdf5a91c32310d552d4c357699ba87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "nanovdb::alignmentPadding", "namespacenanovdb.html#ab5114661378036785ecd28ccef4af4f7", null ],
    [ "nanovdb::alignPtr", "namespacenanovdb.html#accecca045f04c7971c65022455b29d93", null ],
    [ "nanovdb::callNanoGrid", "namespacenanovdb.html#a1b3135f716c47316e3fac411945de505", null ],
    [ "nanovdb::createAccessor", "namespacenanovdb.html#a57196e3b8c9a0bb6c2db0eecac532a3b", null ],
    [ "nanovdb::createAccessor", "namespacenanovdb.html#a757ad702d35c52b48de5efb3b3731422", null ],
    [ "nanovdb::createAccessor", "namespacenanovdb.html#a6357b61877db34bff22f605489ea892f", null ],
    [ "nanovdb::isAligned", "namespacenanovdb.html#a9c70a762c5052ffc60a53f34f9c60395", null ],
    [ "nanovdb::isFloatingPoint", "namespacenanovdb.html#a07d1356890f8bd7328eccd0ef6d6859b", null ],
    [ "nanovdb::isFloatingPointVector", "namespacenanovdb.html#a8e18498be5b1f04f98183216b96f5991", null ],
    [ "nanovdb::isIndex", "namespacenanovdb.html#ab9b68ed29001ffca257c5d7643306da6", null ],
    [ "nanovdb::isInteger", "namespacenanovdb.html#a30dacf83d229d27991e15c5ff1ac4d68", null ],
    [ "nanovdb::isValid", "namespacenanovdb.html#aadeb99b9975910f70061a7e05bdcdfdf", null ],
    [ "nanovdb::isValid", "namespacenanovdb.html#aa8b7a062a229b832fa603cba57fd45b2", null ],
    [ "nanovdb::mapToGridClass", "namespacenanovdb.html#ae3a4415a24f80ce1bc2c47d936cfb29e", null ],
    [ "nanovdb::mapToGridType", "namespacenanovdb.html#a7d6a90b0888cf68599da7f84a34cba0c", null ],
    [ "nanovdb::io::readUncompressedGrids", "namespacenanovdb_1_1io.html#a3c308ceec1559f7bc915fc945e825432", null ],
    [ "nanovdb::io::readUncompressedGrids", "namespacenanovdb_1_1io.html#ac39778460d81e2716a0c1ba0540309fa", null ],
    [ "nanovdb::strlen", "namespacenanovdb.html#a1b76c2c1dee8522993ff9a1ad9ebf696", null ],
    [ "nanovdb::toCheckMode", "namespacenanovdb.html#a1ee58c66a6f478961a2a0841d242ba15", null ],
    [ "nanovdb::io::toCodec", "namespacenanovdb_1_1io.html#a4afb85da61fe99d19cf465508051b3cf", null ],
    [ "nanovdb::toGridClass", "namespacenanovdb.html#afd47b48286b4d63b8f993dc9214c621a", null ],
    [ "nanovdb::toGridType", "namespacenanovdb.html#a1fd46c7c96fb30e3eb3424e20d39273c", null ],
    [ "nanovdb::toMagic", "namespacenanovdb.html#a42a6d5a3554f41e16097456a904b782f", null ],
    [ "nanovdb::io::toStr", "namespacenanovdb_1_1io.html#ade28f9433227abc4a0a09345c24492b9", null ],
    [ "nanovdb::toStr", "namespacenanovdb.html#a6cb4be28da153a7c9563ff3a277e5ab0", null ],
    [ "nanovdb::toStr", "namespacenanovdb.html#a067b4d80252fc3eb9ae76c8bcb0b44c9", null ],
    [ "nanovdb::toStr", "namespacenanovdb.html#a502d64c8e599f96c192772c6b702d675", null ],
    [ "nanovdb::toStr", "namespacenanovdb.html#ae1a25f393cd58e2c66398956b09f2383", null ],
    [ "nanovdb::toStr", "namespacenanovdb.html#a22c8e7ad68f0f547562b7a000402eb92", null ],
    [ "nanovdb::toStr", "namespacenanovdb.html#a9816aa583e468678da051b0e570abf6e", null ],
    [ "nanovdb::io::writeUncompressedGrid", "namespacenanovdb_1_1io.html#a4454feedf9eb64dc06adc3d120a76e9c", null ],
    [ "nanovdb::io::writeUncompressedGrids", "namespacenanovdb_1_1io.html#af12f433e63a43be1f540f7b3c85e99df", null ]
];